@@ -20,15 +20,15 @@
 #' choice as all variables are on the same scale. Other statistics can be
 #' selected using the \code{statistic} argument.
 #'
-#' The result of this function is a \code{\link{ggplot}} object. Most display of
-#' the plot can be manipulated using additional commands appended to the plot
-#' option. For example, the entire theme of the plot can be changed to black and
-#' white using \code{plot(b) + theme_bw()}, where \code{b} is the result of a
-#' call to \code{\link{balanceTest}}. The points on the plot are known as
-#' "values", so colors or symbols used for each strata can be updated using the
-#' \code{\link{scale_color_manual}} function. For example, \code{plot(b) +
-#' scale_color_manaual(values = c('red', 'green', 'blue'))} for a balance test
-#' of three stratification variables.
+#' The result of this function is a \code{\link[ggplot2]{ggplot}} object. Most
+#' display of the plot can be manipulated using additional commands appended to
+#' the plot option. For example, the entire theme of the plot can be changed to
+#' black and white using \code{plot(b) + theme_bw()}, where \code{b} is the
+#' result of a call to \code{\link{balanceTest}}. The points on the plot are
+#' known as "values", so colors or symbols used for each strata can be updated
+#' using the \code{\link[ggplot2]{scale_color_manual}} function. For example,
+#' \code{plot(b) + scale_color_manaual(values = c('red', 'green', 'blue'))} for
+#' a balance test of three stratification variables.
 #'
 #' @param x An object returned by \code{\link{xBalance}}
 #' @param xlab The label for the x-axis of the plot
@@ -45,7 +45,7 @@
 #' grouped.
 #' @param ... additional arguments to pass to \code{\link{balanceplot}}
 #' @return A \code{ggplot2} object that can be further manipulated (e.g., to set the colors or text).
-#' @seealso \code{\link{balanceTest}}, \code{\link{ggplot}}
+#' @seealso \code{\link{balanceTest}}, \code{\link[ggplot2]{ggplot}}
 #' @export
 #' @importFrom tibble rownames_to_column
 #' @importFrom tidyr gather
@@ -61,17 +61,20 @@ plot.balancetest <- function(x,
                              ...) {
   ## this next line is for compatability with Josh's version of the function
   ## while I make it work with the usual plot signature
-  var.order <- NULL; var.grouping <- NULL
+  var.order <- NULL
+  var.grouping <- NULL
 
   stopifnot(is.null(var.order) | is.null(var.grouping))
 
-  tmp <- prepareXbalForPlot(x, statistic, absolute,
-                            strata.labels, variable.labels) #square matrix, each row is row in plot, columns are horizontal locations
-  #plot(tmp)
+  tmp <- prepareXbalForPlot(
+    x, statistic, absolute,
+    strata.labels, variable.labels
+  ) # square matrix, each row is row in plot, columns are horizontal locations
+  # plot(tmp)
   autogroup <- attr(tmp, "term.labels")[attr(tmp, "groups")]
   autogroup[is.na(autogroup)] <- ""
   names(autogroup) <- rownames(tmp)
-  
+
   if (is.null(groups)) {
     groups <- autogroup
   }
@@ -80,14 +83,13 @@ plot.balancetest <- function(x,
 }
 
 balanceTest_ggplot <- function(x,
-                       xlab = "Standardized Differences",
-                       absolute = FALSE,
-                       strata.labels = NULL,
-                       groups = NULL,
-                       var.order = NULL,
-                       var.grouping = NULL,
-                       ...) {
-
+                               xlab = "Standardized Differences",
+                               absolute = FALSE,
+                               strata.labels = NULL,
+                               groups = NULL,
+                               var.order = NULL,
+                               var.grouping = NULL,
+                               ...) {
   # Tidyvers doesn't like rownames
   x <- tibble::as_tibble(x, rownames = "rowname", .name_repair = "unique")
 
@@ -104,11 +106,14 @@ balanceTest_ggplot <- function(x,
   if (!is.null(var.order)) {
     stopifnot(length(var.order) == length(unique(x$rowname)))
     x$rowname <- factor(x$rowname,
-                        levels = rev(var.order))
+      levels = rev(var.order)
+    )
   } else {
     x$rowname <- factor(x$rowname,
-                        levels = sort(unique(x$rowname),
-                                      decreasing = TRUE))
+      levels = sort(unique(x$rowname),
+        decreasing = TRUE
+      )
+    )
   }
 
   if (!is.null(var.grouping)) {
@@ -133,29 +138,35 @@ balanceTest_ggplot <- function(x,
   }
 
   legend.title <- "Stratification" # just giving us some text for now
-  plot <- ggplot2::ggplot(x,
-                          ggplot2::aes(y = .data[["rowname"]],
-                                       x = .data[["value"]],
-                                       color = .data[["strata"]],
-                                       shape = .data[["strata"]])) +
+  plot <- ggplot2::ggplot(
+    x,
+    ggplot2::aes(
+      y = .data[["rowname"]],
+      x = .data[["value"]],
+      color = .data[["strata"]],
+      shape = .data[["strata"]]
+    )
+  ) +
     ggplot2::geom_point(size = 2) +
     ggplot2::geom_vline(xintercept = 0) +
-    ggplot2::labs(color = legend.title,
-                  shape = legend.title,
-                  x = xlab,
-                  y = ggplot2::element_blank())
+    ggplot2::labs(
+      color = legend.title,
+      shape = legend.title,
+      x = xlab,
+      y = ggplot2::element_blank()
+    )
+
+  if (!is.null(x$group) && nlevels(x$group) > 0) {
+    plot <- plot + ggplot2::facet_grid(group ~ ., scales = "free_y", space = "free_y")
+  }
+
 
-    if (!is.null(x$group) && nlevels(x$group) > 0 ) {
-      plot <- plot + ggplot2::facet_grid(group ~ ., scales = "free_y", space = "free_y")
-    }
-  
-  
   # Only draw connectors if there are multiple strata (avoids warning
   # from geom_path)
   if (length(unique(x$strata)) > 1) {
     plot <- plot +
       ggplot2::geom_line(ggplot2::aes(group = .data[["rowname"]]), color = "black")
   }
-    
+
   return(plot)
 }
